@@ -25,7 +25,9 @@ class ClusterConsumer(KafkaConsumer):
         #
         self.consumer = Consumer(self.consumer_config_dict)
         #
-        self.subscribe()
+        list_any_tuple = self.subscribe()
+        if cluster_obj.verbose() > 0:
+            print(list_any_tuple)
 
     def __del__(self):
         self.close()
@@ -66,9 +68,31 @@ class ClusterConsumer(KafkaConsumer):
         #
         message_list = self.consumer.consume(n_int, self.storage_obj.consume_timeout())
         #
-        deserialized_message_dict_list = [{"topic": message.topic(), "headers": message.headers(), "partition": message.partition(), "offset": message.offset(), "timestamp": message.timestamp(), "key": self.deserialize(message.key(), self.topic_str_key_type_str_dict[message.topic()]), "value": self.deserialize(message.value(), self.topic_str_value_type_str_dict[message.topic()])} for message in message_list]
+        message_dict_list = []
+        for message in message_list:
+            if message.error() is None:
+                try:
+                    key_deserialized_payload = self.deserialize(message.key(), self.topic_str_key_type_str_dict[message.topic()], topic_str=message.topic(), key_bool=True)
+                except Exception as e:
+                    raise Exception(f"Error deserializing message key: topic: {message.topic()}, partition: {message.partition()}, offset: {message.offset()}")
+                #
+                try:
+                    value_deserialized_payload = self.deserialize(message.value(), self.topic_str_key_type_str_dict[message.topic()], topic_str=message.topic(), key_bool=False)
+                except Exception as e:
+                    raise Exception(f"Error deserializing message value: topic: {message.topic()}, partition: {message.partition()}, offset: {message.offset()}")
+                #                
+                message_dict = {"topic": message.topic(),
+                                "headers": message.headers(),
+                                "partition": message.partition(),
+                                "offset": message.offset(),
+                                "timestamp": message.timestamp(),
+                                "key": key_deserialized_payload,
+                                "value": value_deserialized_payload}
+            else:
+                raise Exception(f"Error consuming topic(s) {self.topic_str_list}: {message.error().str()}, topic: {message.topic()}, partition: {message.partition()}, offset: {message.offset()}")
+            message_dict_list.append(message_dict)
         #
-        return deserialized_message_dict_list
+        return message_dict_list
 
     #
 
@@ -78,20 +102,20 @@ class ClusterConsumer(KafkaConsumer):
         if offsets is not None:
             str_or_int = list(offsets.keys())[0]
             if isinstance(str_or_int, str):
-                offsets_dict = offsets
+                topic_str_offsets_dict_dict = offsets
             elif isinstance(str_or_int, int):
-                offsets_dict = {topic_str: offsets for topic_str in self.topic_str_list}
+                topic_str_offsets_dict_dict = {topic_str: offsets for topic_str in self.topic_str_list}
             #
-            offsets_topicPartition_list = [TopicPartition(topic_str, partition_int, offset_int) for topic_str, offsets in offsets_dict.items() for partition_int, offset_int in offsets.items()]
+            offsets_topicPartition_list = [TopicPartition(topic_str, partition_int, offset_int) for topic_str, offsets in topic_str_offsets_dict_dict.items() for partition_int, offset_int in offsets.items()]
             #
             commit_topicPartition_list = self.consumer.commit(offsets=offsets_topicPartition_list, asynchronous=asynchronous_bool)
             #
-            offsets_dict = topicPartition_list_to_offsets_dict(commit_topicPartition_list)
+            topic_str_offsets_dict_dict = topicPartition_list_to_offsets_dict(commit_topicPartition_list)
         else:
-            self.consumer.commit()
-            offsets_dict = {}
+            self.consumer.commit() # always returns None in this branch
+            topic_str_offsets_dict_dict = {}
         #
-        return offsets_dict
+        return topic_str_offsets_dict_dict
 
     def offsets(self, **kwargs):
         timeout_float = kwargs["timeout"] if "timeout" in kwargs else -1.0
@@ -99,9 +123,9 @@ class ClusterConsumer(KafkaConsumer):
         assignment_topicPartition_list = self.consumer.assignment()
         committed_topicPartition_list = self.consumer.committed(assignment_topicPartition_list, timeout=timeout_float)
         #
-        offsets_dict = topicPartition_list_to_offsets_dict(committed_topicPartition_list)
+        topic_str_offsets_dict_dict = topicPartition_list_to_offsets_dict(committed_topicPartition_list)
         #
-        return offsets_dict
+        return topic_str_offsets_dict_dict
 
     def memberid(self):
         member_id_str = self.consumer.memberid()
