@@ -10,7 +10,7 @@ ALL_MESSAGES = -1
 #
 
 class Pandas(Functional):
-    def to_df(self, topic, n=ALL_MESSAGES, **kwargs):
+    def topic_to_df(self, topic, n=ALL_MESSAGES, **kwargs):
         #
         def foldl_function(acc, message_dict):
             # df = pd.DataFrame.from_records([message_dict["value"]])
@@ -27,9 +27,10 @@ class Pandas(Functional):
         #
         return df
 
-    def from_df(self, df, topic, n=ALL_MESSAGES, **kwargs):
+    def df_to_topic(self, df, topic, n=ALL_MESSAGES, **kwargs):
         n_int = n
         #
+
         producer = self.producer(topic, **kwargs)
         counter_int = 0
         for _, row in df.iterrows():
@@ -37,14 +38,7 @@ class Pandas(Functional):
                 if counter_int >= n_int:
                     break
             #
-            d = row.to_dict()
-            delete_key_str_list = []
-            for key_str, value in d.items():
-                if pd.isna(value):
-                    delete_key_str_list.append(key_str)
-            for delete_key_str in delete_key_str_list:
-                del d[delete_key_str]
-            producer.produce(d)
+            producer.produce(row.to_dict())
             #
             counter_int += 1
         producer.close()
